==> echarts-5.1.2.jar: META-INF/resources/webjars/echarts/5.1.2/types/src/export/api.d.ts <==
import ComponentModel from '../model/Component';
import ComponentView from '../view/Component';
import SeriesModel from '../model/Series';
import ChartView from '../view/Chart';
export * as zrender from 'zrender/lib/zrender';
export * as matrix from 'zrender/lib/core/matrix';
export * as vector from 'zrender/lib/core/vector';
export * as zrUtil from 'zrender/lib/core/util';
export * as color from 'zrender/lib/tool/color';
export { throttle } from '../util/throttle';
export * as helper from './api/helper';
export { use } from '../extension';
export { default as parseGeoJSON } from '../coord/geo/parseGeoJson';
export { default as parseGeoJson } from '../coord/geo/parseGeoJson';
export * as number from './api/number';
export * as time from './api/time';
export * as graphic from './api/graphic';
export * as format from './api/format';
export * as util from './api/util';
export { default as env } from 'zrender/lib/core/env';
export { default as List } from '../data/List';
export { default as Model } from '../model/Model';
export { default as Axis } from '../coord/Axis';
export { ComponentModel, ComponentView, SeriesModel, ChartView };
export { brushSingle as innerDrawElementOnCanvas } from 'zrender/lib/canvas/graphic';
export declare function extendComponentModel(proto: object): ComponentModel;
export declare function extendComponentView(proto: object): ChartView;
export declare function extendSeriesModel(proto: object): SeriesModel;
export declare function extendChartView(proto: object): ChartView;

==> echarts-5.2.2.jar: META-INF/resources/webjars/echarts/5.2.2/types/src/export/api.d.ts <==
import ComponentModel from '../model/Component';
import ComponentView from '../view/Component';
import SeriesModel from '../model/Series';
import ChartView from '../view/Chart';
import SeriesData from '../data/SeriesData';
export * as zrender from 'zrender/lib/zrender';
export * as matrix from 'zrender/lib/core/matrix';
export * as vector from 'zrender/lib/core/vector';
export * as zrUtil from 'zrender/lib/core/util';
export * as color from 'zrender/lib/tool/color';
export { throttle } from '../util/throttle';
export * as helper from './api/helper';
export { use } from '../extension';
export { default as parseGeoJSON } from '../coord/geo/parseGeoJson';
export { default as parseGeoJson } from '../coord/geo/parseGeoJson';
export * as number from './api/number';
export * as time from './api/time';
export * as graphic from './api/graphic';
export * as format from './api/format';
export * as util from './api/util';
export { default as env } from 'zrender/lib/core/env';
export { SeriesData as List };
export { default as Model } from '../model/Model';
export { default as Axis } from '../coord/Axis';
export { ComponentModel, ComponentView, SeriesModel, ChartView };
export { brushSingle as innerDrawElementOnCanvas } from 'zrender/lib/canvas/graphic';
export declare function extendComponentModel(proto: object): ComponentModel;
export declare function extendComponentView(proto: object): ChartView;
export declare function extendSeriesModel(proto: object): SeriesModel;
export declare function extendChartView(proto: object): ChartView;
